==> haskell-colourista-0.1.0.1-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.1
visibility:           public
id:                   colourista-0.1.0.1-IG26nRI7YIyFW28r6AUZXM
key:                  colourista-0.1.0.1-IG26nRI7YIyFW28r6AUZXM
license:              MPL-2.0
copyright:            2020-2021 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  5ed5ad42330dc760380b14bb254bf877
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.0.2/site-local/colourista-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/colourista-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/colourista-0.1.0.1
hs-libraries:         HScolourista-0.1.0.1-IG26nRI7YIyFW28r6AUZXM
depends:
    ansi-terminal-0.11-7Sg6KtenVNR9Ce5shok5FD base-4.15.1.0
    bytestring-0.10.12.1 ghc-prim-0.7.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colourista-0.1.0.1-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.1
visibility:           public
id:                   colourista-0.1.0.1-FS8gXhN4cgXHEIAI4Xy1hE
key:                  colourista-0.1.0.1-FS8gXhN4cgXHEIAI4Xy1hE
license:              MPL-2.0
copyright:            2020-2021 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  e057725c26a6e4c947fc68d3d295e011
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.0.2/site-local/colourista-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/colourista-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/colourista-0.1.0.1
hs-libraries:         HScolourista-0.1.0.1-FS8gXhN4cgXHEIAI4Xy1hE
depends:
    ansi-terminal-0.11-7Sg6KtenVNR9Ce5shok5FD base-4.15.1.0
    bytestring-0.10.12.1 ghc-prim-0.7.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
